var searchData=
[
  ['k',['K',['../classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html#a372a24837c926db3b9df19f15017182f',1,'Steinberg::Vst::mda::DX10Processor::K()'],['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#a372a24837c926db3b9df19f15017182f',1,'Steinberg::Vst::mda::JX10Processor::K()'],['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a372a24837c926db3b9df19f15017182f',1,'Steinberg::Vst::mda::SpecMeterProcessor::K()'],['../classSteinberg_1_1Vst_1_1mda_1_1TalkBoxProcessor.html#a372a24837c926db3b9df19f15017182f',1,'Steinberg::Vst::mda::TalkBoxProcessor::K()']]],
  ['kallchannelssilent',['kAllChannelsSilent',['../../vstsdk/classSteinberg_1_1Vst_1_1HostProcessData.html#a890c76b22b24ff32c79951b3b25ffbc9',1,'Steinberg::Vst::HostProcessData']]],
  ['kassociatedparameteridvalid',['kAssociatedParameterIDValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a1de059ac90343b011aac2c14646d7ec8a357469987a4f81967855bfc6358a3f39',1,'Steinberg::Vst::NoteExpressionTypeInfo']]],
  ['kbarpositionvalid',['kBarPositionValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a77d6596070548ddebaab07813805b959',1,'Steinberg::Vst::ProcessContext']]],
  ['kblocksize',['kBlockSize',['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716a8355e558f1af9d7da5983731536001ec',1,'Steinberg::Vst::TestEnh']]],
  ['kbuf',['kbuf',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#abcb0b1e5356f9fed7f961c09d0ce0df8',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kbuflen',['kbuflen',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#abd4d3e44e3fbd7661d40dd325438b6a2',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kbufpos',['kbufpos',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#ad97eb308c28919f9cf1fa30d880b920b',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kcanautomate',['kCanAutomate',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645af38562ef6dde00a339d67f9be4ec3a31',1,'Steinberg::Vst::ParameterInfo']]],
  ['kchanged',['kChanged',['../../base/classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a59b6e90764ca9aa343f99c0664410110',1,'Steinberg::IDependent']]],
  ['kchordevent',['kChordEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a4e0a8c28a95df34b9c12c0f226e6923d',1,'Steinberg::Vst::Event']]],
  ['kchordmask',['kChordMask',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Chord.html#a15c053e1a487c607ed4f57d29a07e117a7eebe88f8cafca853fd115af0e1939ab',1,'Steinberg::Vst::Chord']]],
  ['kchordvalid',['kChordValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a2c5aebc70c00b5acda15d34a7d8e6b5d',1,'Steinberg::Vst::ProcessContext']]],
  ['kclass_5fuid',['kCLASS_UID',['../../base/classSteinberg_1_1FUID.html#a4c6d5af58eee71460b173f2a3fc16e83af0e94a5c0c5e442c941dedb3488540dd',1,'Steinberg::FUID']]],
  ['kclassesdiscardable',['kClassesDiscardable',['../../base/structSteinberg_1_1PFactoryInfo.html#a618f56f095d5a47e04cb2a60c9fb7380a76b4fd07aeb307d814444f61a5284c36',1,'Steinberg::PFactoryInfo']]],
  ['kclockvalid',['kClockValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a03449069245e2637f73ef75f0cadc2b0',1,'Steinberg::Vst::ProcessContext']]],
  ['kcomponentnondiscardable',['kComponentNonDiscardable',['../../base/structSteinberg_1_1PFactoryInfo.html#a618f56f095d5a47e04cb2a60c9fb7380acb5680f6a81a74bdfe2cbd8c073df174',1,'Steinberg::PFactoryInfo']]],
  ['kconttimevalid',['kContTimeValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03af574e5e5705f9295d830c4b0de3c3b11',1,'Steinberg::Vst::ProcessContext']]],
  ['kcycleactive',['kCycleActive',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03ae43d6ac7d9f03c335ac275483cd8f303',1,'Steinberg::Vst::ProcessContext']]],
  ['kcyclevalid',['kCycleValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03ab5d7cb7ea333235f0050b65f6865c420',1,'Steinberg::Vst::ProcessContext']]],
  ['kdataevent',['kDataEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a62a25bd1cd5f061e9897cc7315f6763a',1,'Steinberg::Vst::Event']]],
  ['kdeclare_5fuid',['kDECLARE_UID',['../../base/classSteinberg_1_1FUID.html#a4c6d5af58eee71460b173f2a3fc16e83a0645d915ab71dfc6a46b46b2e0437b01',1,'Steinberg::FUID']]],
  ['kdefaultactive',['kDefaultActive',['../../vstinterfaces/structSteinberg_1_1Vst_1_1BusInfo.html#a764af5c5b921de1cab2eca6565ea5d1eace2379dbcd61f72660abb9243cb55bc6',1,'Steinberg::Vst::BusInfo']]],
  ['kdel',['kdel',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a808676e20a0c690515cb5eb02790f6e2',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kdestroyed',['kDestroyed',['../../base/classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a3d6cbd03cda4f9fc9018d975f978a1f1',1,'Steinberg::IDependent']]],
  ['kdroprate',['kDropRate',['../../vstinterfaces/structSteinberg_1_1Vst_1_1FrameRate.html#a0e1b90fc53cc88f751388bc4466a4665a859f363f2bc4f6bb60331d4106870722',1,'Steinberg::Vst::FrameRate']]],
  ['keventbuffersize',['kEventBufferSize',['../classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html#a38dc2d19e777233d1760e4d12c84d45a',1,'Steinberg::Vst::mda::DX10Processor::kEventBufferSize()'],['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a38dc2d19e777233d1760e4d12c84d45a',1,'Steinberg::Vst::mda::EPianoProcessor::kEventBufferSize()'],['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#a38dc2d19e777233d1760e4d12c84d45a',1,'Steinberg::Vst::mda::JX10Processor::kEventBufferSize()'],['../classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html#a38dc2d19e777233d1760e4d12c84d45a',1,'Steinberg::Vst::mda::PianoProcessor::kEventBufferSize()']]],
  ['keyboardrange',['keyboardRange',['../classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1ControllerWithUI.html#ab86046c9174e294df454f1b7ac321e7e',1,'Steinberg::Vst::NoteExpressionSynth::ControllerWithUI']]],
  ['keynote',['keyNote',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Chord.html#a4aaf84930c8913e7e3712874f2a5e04a',1,'Steinberg::Vst::Chord']]],
  ['keyremapped',['keyRemapped',['../../vstinterfaces/structSteinberg_1_1Vst_1_1KeyswitchInfo.html#aaa5123c15f3514c8e4db594017c44130',1,'Steinberg::Vst::KeyswitchInfo']]],
  ['keyswitchmax',['keyswitchMax',['../../vstinterfaces/structSteinberg_1_1Vst_1_1KeyswitchInfo.html#a5d0850732b1e666e3290b647f9ecf827',1,'Steinberg::Vst::KeyswitchInfo']]],
  ['keyswitchmin',['keyswitchMin',['../../vstinterfaces/structSteinberg_1_1Vst_1_1KeyswitchInfo.html#a7e41662b9becfa89e607e82e3b38d264',1,'Steinberg::Vst::KeyswitchInfo']]],
  ['kfil1',['kfil1',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a356e2961aa9c4ed427743fc3c92d2e40',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kfil2',['kfil2',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a759fb209763a90e454cbc5fd621d17cd',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kfuid',['kFUID',['../../base/classSteinberg_1_1FUID.html#a4c6d5af58eee71460b173f2a3fc16e83a786d38db04f85fa7d41ffb4bfdb38283',1,'Steinberg::FUID']]],
  ['kgrp',['kgrp',['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a66cb14ce40d28dd393c60876e775197a',1,'Steinberg::Vst::mda::EPianoProcessor::kgrp()'],['../classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html#ad7192324f8580ae8c0de22bdc7e83b35',1,'Steinberg::Vst::mda::PianoProcessor::kgrp()']]],
  ['kibseekcur',['kIBSeekCur',['../../base/classSteinberg_1_1IBStream.html#a578603bbda4a0145412cb895b14efdd4a38fe1bc7808828aa43282a56e5ed70f1',1,'Steinberg::IBStream']]],
  ['kibseekend',['kIBSeekEnd',['../../base/classSteinberg_1_1IBStream.html#a578603bbda4a0145412cb895b14efdd4aee2005d02e649de8da100c7f417cc2d8',1,'Steinberg::IBStream']]],
  ['kibseekset',['kIBSeekSet',['../../base/classSteinberg_1_1IBStream.html#a578603bbda4a0145412cb895b14efdd4aa6df685ae526fa7efefe23ce2c5e6e97',1,'Steinberg::IBStream']]],
  ['kinline_5fuid',['kINLINE_UID',['../../base/classSteinberg_1_1FUID.html#a4c6d5af58eee71460b173f2a3fc16e83a9f131fba80cf6b9f835dbcd1893a8e2a',1,'Steinberg::FUID']]],
  ['kisabsolute',['kIsAbsolute',['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a1de059ac90343b011aac2c14646d7ec8aef666cae7e4e80d922765cfe99da015f',1,'Steinberg::Vst::NoteExpressionTypeInfo']]],
  ['kisbipolar',['kIsBipolar',['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a1de059ac90343b011aac2c14646d7ec8a0cf6a1d666d333bc4c2863557e013245',1,'Steinberg::Vst::NoteExpressionTypeInfo']]],
  ['kisbypass',['kIsBypass',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645af9d12238330266160c4c36bac7a76622',1,'Steinberg::Vst::ParameterInfo']]],
  ['kischecked',['kIsChecked',['../../vstinterfaces/structSteinberg_1_1Vst_1_1IContextMenuItem.html#aa705cf7e79a21c2352b00ffe20cd295fa877e05e66286af1b983c061e6d46dda0',1,'Steinberg::Vst::IContextMenuItem']]],
  ['kiscontrolvoltage',['kIsControlVoltage',['../../vstinterfaces/structSteinberg_1_1Vst_1_1BusInfo.html#a764af5c5b921de1cab2eca6565ea5d1ead4866d347690f538cd3dd9ba04af86d6',1,'Steinberg::Vst::BusInfo']]],
  ['kisdisabled',['kIsDisabled',['../../vstinterfaces/structSteinberg_1_1Vst_1_1IContextMenuItem.html#aa705cf7e79a21c2352b00ffe20cd295fa2206f46f57bc94b30fe890f42c64c303',1,'Steinberg::Vst::IContextMenuItem']]],
  ['kisgroupend',['kIsGroupEnd',['../../vstinterfaces/structSteinberg_1_1Vst_1_1IContextMenuItem.html#aa705cf7e79a21c2352b00ffe20cd295fade2b2aeffaec861931cf871d56e22bcf',1,'Steinberg::Vst::IContextMenuItem']]],
  ['kisgroupstart',['kIsGroupStart',['../../vstinterfaces/structSteinberg_1_1Vst_1_1IContextMenuItem.html#aa705cf7e79a21c2352b00ffe20cd295fa9d61fc687d4b6b50d56db8afe6011d57',1,'Steinberg::Vst::IContextMenuItem']]],
  ['kishidden',['kIsHidden',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645a151362a1bf785d44446da650c8833c92',1,'Steinberg::Vst::ParameterInfo']]],
  ['kislist',['kIsList',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645a1d80e03f3f6f05a10b4bd1778c00e901',1,'Steinberg::Vst::ParameterInfo']]],
  ['kislive',['kIsLive',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5a8b9e49c3d94641913c8098c23c25b125',1,'Steinberg::Vst::Event']]],
  ['kisoneshot',['kIsOneShot',['../../vstinterfaces/structSteinberg_1_1Vst_1_1NoteExpressionTypeInfo.html#a1de059ac90343b011aac2c14646d7ec8aa9c080ea5298ee26364097f0ebc2c736',1,'Steinberg::Vst::NoteExpressionTypeInfo']]],
  ['kisprogramchange',['kIsProgramChange',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645a517665185bca1f4f3d77ce0a6468b8e3',1,'Steinberg::Vst::ParameterInfo']]],
  ['kisreadonly',['kIsReadOnly',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645a6d0f0315e38602bca6847abb752ab10f',1,'Steinberg::Vst::ParameterInfo']]],
  ['kisseparator',['kIsSeparator',['../../vstinterfaces/structSteinberg_1_1Vst_1_1IContextMenuItem.html#aa705cf7e79a21c2352b00ffe20cd295faeeede7e231c10707303ad1084bb20519',1,'Steinberg::Vst::IContextMenuItem']]],
  ['kiswraparound',['kIsWrapAround',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645ab6db0c541e451f24f819ab231f3ecf96',1,'Steinberg::Vst::ParameterInfo']]],
  ['klegacymidiccoutevent',['kLegacyMIDICCOutEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a85daeaf98e74f3c670b9939c78794b95',1,'Steinberg::Vst::Event']]],
  ['klev',['klev',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a18143059ad8aa26ecc150d882ab5d311',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['klicensecheck',['kLicenseCheck',['../../base/structSteinberg_1_1PFactoryInfo.html#a618f56f095d5a47e04cb2a60c9fb7380a33a11b36601c0392f96fe277213bf94b',1,'Steinberg::PFactoryInfo']]],
  ['kmanyinstances',['kManyInstances',['../../base/structSteinberg_1_1PClassInfo.html#aab16066f9ae5683da7458b67a11eeecea5cd6f16a8a935a43a15d03e4c50782f2',1,'Steinberg::PClassInfo']]],
  ['kmax',['KMAX',['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#a5e0b745fc532cdbf2e422cb53a9433a0',1,'Steinberg::Vst::mda::JX10Processor::KMAX()'],['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#aab2a64af69bf15b9af72e1ce7563efd1',1,'Steinberg::Vst::mda::SpecMeterProcessor::kmax()']]],
  ['kmaxevents',['kMaxEvents',['../classEventListCheck.html#a4a3a20bfac766aa19e01388ff52af5b6',1,'EventListCheck']]],
  ['kmaxlatency',['kMaxLatency',['../namespaceSteinberg_1_1HostChecker.html#ae3d4ad032b2586752aaefe7d98b3b352',1,'Steinberg::HostChecker']]],
  ['kmaxsamplesperblock',['kMaxSamplesPerBlock',['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716a9b13d2a9d89354f5b3252d7312cd6abb',1,'Steinberg::Vst::TestEnh']]],
  ['kmicrosecondsstring',['kMicroSecondsString',['../classSteinberg_1_1Vst_1_1mda_1_1BaseController.html#ae5d3e4694c89627f8012d679bee40481',1,'Steinberg::Vst::mda::BaseController']]],
  ['kmidisysex',['kMidiSysEx',['../../vstinterfaces/structSteinberg_1_1Vst_1_1DataEvent.html#afb6eb4f28419b652027fad41104a6d22ab06d86440be6a85eccce4df100ce8e79',1,'Steinberg::Vst::DataEvent']]],
  ['kneedbarpositionmusic',['kNeedBarPositionMusic',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa134cafe5a9c33ed27acdcb25e940863a',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedchord',['kNeedChord',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fafb72587bd903135883991114527e6f1d',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedcontinoustimesamples',['kNeedContinousTimeSamples',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295faa9e82d888237c29f06fcd8fcf443b20b',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedcyclemusic',['kNeedCycleMusic',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa683a21508fbe72f10289ded4fc2b44a6',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedframerate',['kNeedFrameRate',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295faeefe9f93afa959b33c00ea3ec1373b2d',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedprojecttimemusic',['kNeedProjectTimeMusic',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fab82decaf7fc62b5057ed93f563ed4945',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedsamplestonextclock',['kNeedSamplesToNextClock',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa69817b6abbfd3520c38372033983ceba',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedsystemtime',['kNeedSystemTime',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa1769a21eea7bccd291b0db98c58e29e8',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedtempo',['kNeedTempo',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa2c4c819b006ecaf5f4a9019e27db78fb',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedtimesignature',['kNeedTimeSignature',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa70305b15a471a18eda82a146f2d0847b',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['kneedtransportstate',['kNeedTransportState',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fa98d6bb4315562bcdb2d6bd57da499ea5',1,'Steinberg::Vst::IProcessContextRequirements']]],
  ['knoautomation',['kNoAutomation',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IAutomationState.html#a787ff792c6d9eaf7652cef4454750adba50593589ab3b2b6bc94d914caf926e8a',1,'Steinberg::Vst::IAutomationState']]],
  ['knoflags',['kNoFlags',['../../base/structSteinberg_1_1PFactoryInfo.html#a618f56f095d5a47e04cb2a60c9fb7380aacc42d61d53f9b50d3f1f3b463ede0b5',1,'Steinberg::PFactoryInfo::kNoFlags()'],['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645aacc42d61d53f9b50d3f1f3b463ede0b5',1,'Steinberg::Vst::ParameterInfo::kNoFlags()']]],
  ['knormtuningoneoctave',['kNormTuningOneOctave',['../classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1VoiceStatics.html#a3d5ca94d33d5e124305a6ef08d2958c5',1,'Steinberg::Vst::NoteExpressionSynth::VoiceStatics']]],
  ['knormtuningonetune',['kNormTuningOneTune',['../classSteinberg_1_1Vst_1_1NoteExpressionSynth_1_1VoiceStatics.html#a7ca02bb1ad97593cdafda8b7fc813304',1,'Steinberg::Vst::NoteExpressionSynth::VoiceStatics']]],
  ['knoteexpressiontextevent',['kNoteExpressionTextEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a494e407c199f55129c93f53bd5cada93',1,'Steinberg::Vst::Event']]],
  ['knoteexpressionvalueevent',['kNoteExpressionValueEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a18b62187f591a8e615ef6c934461db2d',1,'Steinberg::Vst::Event']]],
  ['knoteoffevent',['kNoteOffEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a1cabbcf11ce8779b94e6cfa480d87b09',1,'Steinberg::Vst::Event']]],
  ['knoteonevent',['kNoteOnEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a6969fd08df9f0611a6566e93c0c31e42',1,'Steinberg::Vst::Event']]],
  ['knumprograms',['kNumPrograms',['../classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html#a46709d21fb3511769bcf9e31046d4531',1,'Steinberg::Vst::mda::DX10Processor::kNumPrograms()'],['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a46709d21fb3511769bcf9e31046d4531',1,'Steinberg::Vst::mda::EPianoProcessor::kNumPrograms()'],['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#a46709d21fb3511769bcf9e31046d4531',1,'Steinberg::Vst::mda::JX10Processor::kNumPrograms()'],['../classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html#a46709d21fb3511769bcf9e31046d4531',1,'Steinberg::Vst::mda::PianoProcessor::kNumPrograms()']]],
  ['knumvoices',['kNumVoices',['../classSteinberg_1_1Vst_1_1mda_1_1DX10Processor.html#afb565af78042a78acd0b4294f588c34f',1,'Steinberg::Vst::mda::DX10Processor::kNumVoices()'],['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#afb565af78042a78acd0b4294f588c34f',1,'Steinberg::Vst::mda::EPianoProcessor::kNumVoices()'],['../classSteinberg_1_1Vst_1_1mda_1_1JX10Processor.html#afb565af78042a78acd0b4294f588c34f',1,'Steinberg::Vst::mda::JX10Processor::kNumVoices()'],['../classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html#afb565af78042a78acd0b4294f588c34f',1,'Steinberg::Vst::mda::PianoProcessor::kNumVoices()']]],
  ['kparamunitstruct1count',['kParamUnitStruct1Count',['../namespaceSteinberg_1_1HostChecker.html#ad4383350836de663faf25e58dc9b6529',1,'Steinberg::HostChecker']]],
  ['kparamunitstruct2count',['kParamUnitStruct2Count',['../namespaceSteinberg_1_1HostChecker.html#a097fa93de17b33e8238e948e44f01527',1,'Steinberg::HostChecker']]],
  ['kparamunitstruct3count',['kParamUnitStruct3Count',['../namespaceSteinberg_1_1HostChecker.html#a378cad607bca2ff3c5374cc956760452',1,'Steinberg::HostChecker']]],
  ['kparamunitstructcount',['kParamUnitStructCount',['../namespaceSteinberg_1_1HostChecker.html#a84a49c10ae740d6cf7b295f653712274',1,'Steinberg::HostChecker']]],
  ['kparamwarnbitcount',['kParamWarnBitCount',['../namespaceSteinberg_1_1HostChecker.html#a72e8435dc9b0315802adde434a4fcd14',1,'Steinberg::HostChecker']]],
  ['kparamwarncount',['kParamWarnCount',['../namespaceSteinberg_1_1HostChecker.html#a82a59297717d21868266e8a4fd1da4f0',1,'Steinberg::HostChecker']]],
  ['kparamwarnstepcount',['kParamWarnStepCount',['../namespaceSteinberg_1_1HostChecker.html#a4bc22a30a6391416bcaa23b915d31916',1,'Steinberg::HostChecker']]],
  ['kplatformtypehiview',['kPlatformTypeHIView',['../../vstinterfaces/group__platformUIType.html#ga974cabea219cb31ad8218ba15d1f7071',1,]]],
  ['kplatformtypehwnd',['kPlatformTypeHWND',['../../vstinterfaces/group__platformUIType.html#gaa1e68ac1f25da9c85c937d0360dbc601',1,]]],
  ['kplatformtypensview',['kPlatformTypeNSView',['../../vstinterfaces/group__platformUIType.html#ga8ce69944b5475d65206469b9ebcbf755',1,]]],
  ['kplatformtypeuiview',['kPlatformTypeUIView',['../../vstinterfaces/group__platformUIType.html#ga6362a7ca65b87d30c561dac986b757bd',1,]]],
  ['kplatformtypex11embedwindowid',['kPlatformTypeX11EmbedWindowID',['../../vstinterfaces/group__platformUIType.html#gac945decc5f26f3fdb5419e8de833a0e1',1,]]],
  ['kplaying',['kPlaying',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a5b645fba782b3b038ecc301c60b65114',1,'Steinberg::Vst::ProcessContext']]],
  ['kpolypressureevent',['kPolyPressureEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a5800a14018dee96cd41f5f10691b8b85',1,'Steinberg::Vst::Event']]],
  ['kprojecttimemusicvalid',['kProjectTimeMusicValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a4ef3fb8e987fdda3228d0a2ab40ffce5',1,'Steinberg::Vst::ProcessContext']]],
  ['kpulldownrate',['kPullDownRate',['../../vstinterfaces/structSteinberg_1_1Vst_1_1FrameRate.html#a0e1b90fc53cc88f751388bc4466a4665aa2055ed514ccc81c537ca60ddbdaa226',1,'Steinberg::Vst::FrameRate']]],
  ['kreadstate',['kReadState',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IAutomationState.html#a787ff792c6d9eaf7652cef4454750adba27168d4bbe8c328ccc1c61c18e5e86cf',1,'Steinberg::Vst::IAutomationState']]],
  ['kreadwritestate',['kReadWriteState',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IAutomationState.html#a787ff792c6d9eaf7652cef4454750adba91c9e6284228f8fed9c09539698ff6c1',1,'Steinberg::Vst::IAutomationState']]],
  ['krecording',['kRecording',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a7c3dd7bb52ddb9f7557a8cb32d38ea2b',1,'Steinberg::Vst::ProcessContext']]],
  ['kreservedmask',['kReservedMask',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Chord.html#a15c053e1a487c607ed4f57d29a07e117a4604f8115055d6e83aa00610b65a290c',1,'Steinberg::Vst::Chord']]],
  ['ksamplerate',['kSampleRate',['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716aaa20000cdc4614e9b78a9ab7b85b3137',1,'Steinberg::Vst::TestEnh']]],
  ['ksb1',['ksb1',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a1eefc766535d1aa72bd2d09798a09029',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['ksb2',['ksb2',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a3b46e43d4c3532e4eb828f42f77fdded',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kscaleevent',['kScaleEvent',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#a914d2da0ec9f0e22cd5e400bc1f968b8a1fcf9cd0ded093f84e9b0a8177679ad4',1,'Steinberg::Vst::Event']]],
  ['ksf1',['ksf1',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a7c9da670ec8cdff2e7ac0b5c7e4e3203',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['ksf2',['ksf2',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a2fcf39d67fb99df9008f94fe364064b2',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['ksfx',['ksfx',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a45c5179906935873a8f16f14f57ddd03',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['ksizeparamtag',['kSizeParamTag',['../classSteinberg_1_1Vst_1_1EditorSizeController.html#a53fca78841fd083cb814731f96f6020c',1,'Steinberg::Vst::EditorSizeController']]],
  ['ksmptevalid',['kSmpteValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a2326f930282bcaa6323a4482b3772ce3',1,'Steinberg::Vst::ProcessContext']]],
  ['kstdchangemessagelast',['kStdChangeMessageLast',['../../base/classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1ad4ccb3c09b77e5ca9c19831a56d06712',1,'Steinberg::IDependent']]],
  ['ksystemtimevalid',['kSystemTimeValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03a53fb5555d770366b370d9cf1dce63785',1,'Steinberg::Vst::ProcessContext']]],
  ['ktempovalid',['kTempoValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03aede1cd4db7eec7e4680d7cc50dffc965',1,'Steinberg::Vst::ProcessContext']]],
  ['kthr',['kthr',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#ab52edd74bef6d42b4159e561747c64c5',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['ktimesigvalid',['kTimeSigValid',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a7ac64bdb8f6c1e2d67da949940d46d03ab1b4bad2bca898aadd1c5c352d72af3c',1,'Steinberg::Vst::ProcessContext']]],
  ['kunicode',['kUnicode',['../../base/structSteinberg_1_1PFactoryInfo.html#a618f56f095d5a47e04cb2a60c9fb7380aab221417e3c0a7c87707b0a5b80c9209',1,'Steinberg::PFactoryInfo']]],
  ['kuserreserved1',['kUserReserved1',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5a62708aba77581182dffd7458cf6b621e',1,'Steinberg::Vst::Event']]],
  ['kuserreserved2',['kUserReserved2',['../../vstinterfaces/structSteinberg_1_1Vst_1_1Event.html#ab52fb080a2898a94efbd54969f61e5d5aa0fac77d8173c8ca51fb73ae6177181b',1,'Steinberg::Vst::Event']]],
  ['kvstaudioeffectclass',['kVstAudioEffectClass',['../againentry_8cpp.html#a747235f6e5700e3fbd1d59010b512b50',1,'kVstAudioEffectClass():&#160;againentry.cpp'],['../channelcontext_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357',1,'kVstAudioEffectClass():&#160;plugentry.cpp'],['../note__expression__text_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357',1,'kVstAudioEffectClass():&#160;plugentry.cpp'],['../prefetchablesupport_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357',1,'kVstAudioEffectClass():&#160;plugentry.cpp'],['../programchange_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357',1,'kVstAudioEffectClass():&#160;plugentry.cpp']]],
  ['kvstversionstring',['kVstVersionString',['../againentry_8cpp.html#ad55a4f99f6b826bc06bf14e8d8473ca2',1,'kVstVersionString():&#160;againentry.cpp'],['../channelcontext_2source_2plugentry_8cpp.html#a8e474a03994aa5c0ee4068ec2b3b7217',1,'kVstVersionString():&#160;plugentry.cpp'],['../note__expression__text_2source_2plugentry_8cpp.html#af95bfaaff460967d112f7e5db4232ea2',1,'kVstVersionString():&#160;plugentry.cpp'],['../prefetchablesupport_2source_2plugentry_8cpp.html#a29707ed5621830ba9ca420b63a42b48d',1,'kVstVersionString():&#160;plugentry.cpp'],['../programchange_2source_2plugentry_8cpp.html#ac1309796378f282dc0a0d07f322a9727',1,'kVstVersionString():&#160;plugentry.cpp']]],
  ['kwillchange',['kWillChange',['../../base/classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1a12898124f259d06a01da2fbec93b62b7',1,'Steinberg::IDependent']]],
  ['kwilldestroy',['kWillDestroy',['../../base/classSteinberg_1_1IDependent.html#a4b88d1d42482ecad4964cf7c7f35b8c1aefbe6c668f52e8e2dd07b06025691c9e',1,'Steinberg::IDependent']]],
  ['kwritestate',['kWriteState',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IAutomationState.html#a787ff792c6d9eaf7652cef4454750adbad3b29f3c6c1d4b45e32c9782ac13b4ad',1,'Steinberg::Vst::IAutomationState']]],
  ['kww',['kww',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a1eeddc96f428b15514dd789857ddd147',1,'Steinberg::Vst::mda::BeatBoxProcessor']]],
  ['kwwx',['kwwx',['../classSteinberg_1_1Vst_1_1mda_1_1BeatBoxProcessor.html#a005bcf6adb17a8587f367593888d7ece',1,'Steinberg::Vst::mda::BeatBoxProcessor']]]
];
